==> grc-ui-container-v2.2.10-3.tar.gz: grc-ui-container-v2.2.10-3/app/tests/cypress/tests/demos/policy-demo.spec.js <==
/* Copyright (c) 2020 Red Hat, Inc. */
/// <reference types="cypress" />
import {
  createPolicyFromYAML, verifyPolicyInListing, verifyPolicyNotInListing,
  actionPolicyActionInListing, getDefaultSubstitutionRules,
  verifyPlacementRuleInPolicyDetails, verifyPlacementBindingInPolicyDetails,
  verifyPolicyInPolicyDetails, verifyPolicyInPolicyDetailsTemplates
} from '../../views/policy'
import { getUniqueResourceName } from '../../scripts/utils'
import { getConfigObject } from '../../config'

describe('Testing policy named demo-policy in demo.yaml file', () => {
    const policyName = 'demo-policy'
    const uPolicyName = getUniqueResourceName(policyName)
    // demo-policy-raw.yaml is used for creating the policy "demo-policy"
    // demo-policy-raw.yaml is raw policy yaml and need be to get as raw data
    const policyYAML = getConfigObject('sample/demo-policy-raw.yaml', 'raw', getDefaultSubstitutionRules({policyname:uPolicyName}))
    // demo-policy-config.yaml is used for validating the policy "demo-policy"
    // demo-policy-config.yaml isn't raw policy yaml but config yaml and need be converted to a dictionary
    const { policyConfig } = getConfigObject('sample/demo-policy-config.yaml')
    const confClusterViolations = getConfigObject('sample/violations.yaml', 'yaml', getDefaultSubstitutionRules({policyname:policyName}))

    it (`Can create new policy ${uPolicyName} from YAML editor`, () => {
      cy.FromGRCToCreatePolicyPage()
      createPolicyFromYAML(policyYAML, true)
    })

    it(`Policy ${uPolicyName} is present in the policy listing`, () => {
      verifyPolicyInListing(uPolicyName,  policyConfig)
    })

    it('Policy status becomes available', () => {
      // cy.visit(`/multicloud/policies/all/${policies[name]['namespace']}/${uPolicyName}`)
      // or cy.visit('/multicloud/policies/all')
      // both pages should be supported
      cy.waitForPolicyStatus(uPolicyName)
    })

    it('Disable policy', () => {
      actionPolicyActionInListing(uPolicyName, 'Disable')
    })

    it('Check disabled policy', () => {
      verifyPolicyInListing(uPolicyName,  policyConfig, 'disabled')
    })

    it('Enable policy', () => {
      actionPolicyActionInListing(uPolicyName, 'Enable')
    })

    it('Check enabled policy', () => {
      verifyPolicyInListing(uPolicyName,  policyConfig, 'enabled', '0/1')
    })

    it('Enforce policy', () => {
      actionPolicyActionInListing(uPolicyName, 'Enforce')
    })

    it('Check enforced policy', () => {
       policyConfig.enforce = true
       policyConfig.inform = false
      verifyPolicyInListing(uPolicyName,  policyConfig)
    })

    it('Inform policy', () => {
      actionPolicyActionInListing(uPolicyName, 'Inform')
    })

    it('Check informed policy', () => {
       policyConfig.enforce = false
       policyConfig.inform = true
      verifyPolicyInListing(uPolicyName,  policyConfig)
    })

    it('check policy and the detailed policy page', () => {
       // we need to find another way how to access this page
       cy.goToPolicyDetailsPage(uPolicyName, policyConfig['namespace'])
         .then(() => {
           verifyPolicyInPolicyDetails(uPolicyName, policyConfig, 'enabled', '0/1')
           verifyPolicyInPolicyDetailsTemplates(uPolicyName, policyConfig)
           verifyPlacementRuleInPolicyDetails(uPolicyName, policyConfig, confClusterViolations)
           verifyPlacementBindingInPolicyDetails(uPolicyName, policyConfig)
         })
    })

    it(`Policy ${uPolicyName} can be deleted in the policy listing`, () => {
      // we could use a different way how to return to this page
      cy.visit('/multicloud/policies/all')
      actionPolicyActionInListing(uPolicyName, 'Remove')
    })

    it(`Deleted policy ${uPolicyName} is not present in the policy listing`, () => {
      verifyPolicyNotInListing(uPolicyName)
    })
})

==> grc-ui-container-v2.3.0-100.tar.gz: grc-ui-container-v2.3.0-100/app/tests/cypress/tests/demos/policy-demo.spec.js <==
/* Copyright (c) 2020 Red Hat, Inc. */
/* Copyright Contributors to the Open Cluster Management project */

/// <reference types="cypress" />
import { getDefaultSubstitutionRules } from '../../support/views'
import { getUniqueResourceName } from '../../scripts/utils'
import { getConfigObject } from '../../config'

describe('Testing policy named demo-policy in demo.yaml file', () => {
    const policyName = 'demo-policy'
    const uPolicyName = getUniqueResourceName(policyName)
    // demo-policy-raw.yaml is used for creating the policy "demo-policy"
    // demo-policy-raw.yaml is raw policy yaml and need be to get as raw data
    const policyYAML = getConfigObject('demos/policy-demo/demo-policy-raw.yaml', 'raw', getDefaultSubstitutionRules({policyname:uPolicyName}))
    // demo-policy-config.yaml is used for validating the policy "demo-policy"
    // demo-policy-config.yaml isn't raw policy yaml but config yaml and need be converted to a dictionary
    const { policyConfig } = getConfigObject('demos/policy-demo/demo-policy-config.yaml')

    it (`Can create new policy ${uPolicyName} from YAML editor`, () => {
      cy.FromGRCToCreatePolicyPage()
        .createPolicyFromYAML(policyYAML, true)
    })

    it(`Policy ${uPolicyName} is present in the policy listing`, () => {
      cy.verifyPolicyInListing(uPolicyName, policyConfig)
    })

    it('Policy status becomes available', () => {
      // cy.visit(`/multicloud/policies/all/${policies[name]['namespace']}/${uPolicyName}`)
      // or cy.visit('/multicloud/policies/all')
      // both pages should be supported
      cy.waitForPolicyStatus(uPolicyName)
    })

    it('Disable policy', () => {
      cy.actionPolicyActionInListing(uPolicyName, 'Disable')
    })

    it('Check disabled policy', () => {
      cy.verifyPolicyInListing(uPolicyName, policyConfig, 'disabled')
    })

    it('Enable policy', () => {
      cy.actionPolicyActionInListing(uPolicyName, 'Enable')
    })

    it('Check enabled policy', () => {
      cy.verifyPolicyInListing(uPolicyName, policyConfig, 'enabled', '0/1')
    })

    it('Enforce policy', () => {
      cy.actionPolicyActionInListing(uPolicyName, 'Enforce')
    })

    it('Check enforced policy', () => {
      policyConfig.remediation = true
      cy.verifyPolicyInListing(uPolicyName, policyConfig)
    })

    it('Inform policy', () => {
      cy.actionPolicyActionInListing(uPolicyName, 'Inform')
    })

    it('Check informed policy', () => {
      policyConfig.remediation = false
      cy.verifyPolicyInListing(uPolicyName, policyConfig)
    })

    it('check policy and the detailed policy page', () => {
       // we need to find another way how to access this page
       cy.goToPolicyDetailsPage(uPolicyName, policyConfig['namespace'])
         .verifyPolicyInPolicyDetails(uPolicyName, policyConfig, 'enabled', '0/1')
    })

    it(`Policy ${uPolicyName} can be deleted in the policy listing`, () => {
      // we could use a different way how to return to this page
      cy.visit('/multicloud/policies/all')
        .actionPolicyActionInListing(uPolicyName, 'Delete')
    })

    it(`Deleted policy ${uPolicyName} is not present in the policy listing`, () => {
      cy.verifyPolicyNotInListing(uPolicyName)
    })
})
